@@ -4,10 +4,10 @@
 #include <QString>
 
 #define __VYM_NAME "VYM"
-#define __VYM_VERSION "1.12.7"
-#define __VYM_CODENAME "Windows version"
-//#define __VYM_CODENAME "Codename: development version"
-#define __VYM_BUILD_DATE "2010-03-05"
+#define __VYM_VERSION "1.99.0"
+#define __VYM_CODENAME "Codename: RC-1"
+//#define __VYM_CODENAME "Codename: development version, not for production!"
+#define __VYM_BUILD_DATE "2011-09-21"
 
 
 bool checkVersion(const QString &);
